@@ -18,7 +18,7 @@
 # those files. Users are asked to read the 3rd Party Licenses
 # referenced with those assets.
 #
-# Copyright (c) 2022 Tom Kralidis
+# Copyright (c) 2025 Tom Kralidis
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -53,23 +53,27 @@ LOGGER = logging.getLogger(__name__)
 THISDIR = os.path.dirname(os.path.realpath(__file__))
 
 SCHEMAS = {
+    'dcat': 'pygeometa.schemas.dcat.DCATOutputSchema',
     'iso19139': 'pygeometa.schemas.iso19139.ISO19139OutputSchema',
     'iso19139-2': 'pygeometa.schemas.iso19139_2.ISO19139_2OutputSchema',
     'iso19139-hnap': 'pygeometa.schemas.iso19139_hnap.ISO19139HNAPOutputSchema',  # noqa
     'oarec-record': 'pygeometa.schemas.ogcapi_records.OGCAPIRecordOutputSchema',  # noqa
+    'schema-org': 'pygeometa.schemas.schema_org.SchemaOrgOutputSchema',
     'stac-item': 'pygeometa.schemas.stac.STACItemOutputSchema',
-    'dcat': 'pygeometa.schemas.dcat.DCATOutputSchema',
     'wmo-cmp': 'pygeometa.schemas.wmo_cmp.WMOCMPOutputSchema',
     'wmo-wcmp2': 'pygeometa.schemas.wmo_wcmp2.WMOWCMP2OutputSchema',
-    'wmo-wigos': 'pygeometa.schemas.wmo_wigos.WMOWIGOSOutputSchema'
+    'wmo-wigos': 'pygeometa.schemas.wmo_wigos.WMOWIGOSOutputSchema',
+    'cwl': 'pygeometa.schemas.cwl.CWLOutputSchema'
 }
 
 
-def get_supported_schemas(details: bool = False) -> list:
+def get_supported_schemas(details: bool = False,
+                          include_autodetect: bool = False) -> list:
     """
     Get supported schemas
 
     :param details: provide read/write details
+    :param include_autodetect: include magic auto detection mode
 
     :returns: list of supported schemas
     """
@@ -91,7 +95,12 @@ def get_supported_schemas(details: bool = False) -> list:
     LOGGER.debug('Generating list of supported schemas')
 
     if not details:
-        return SCHEMAS.keys()
+        if include_autodetect:
+            schemas_keys = list(SCHEMAS.keys())
+            schemas_keys.append('autodetect')
+            return schemas_keys
+        else:
+            return SCHEMAS.keys()
 
     for key in SCHEMAS.keys():
         schema = load_schema(key)
@@ -105,6 +114,14 @@ def get_supported_schemas(details: bool = False) -> list:
             'write': can_write
         })
 
+    if include_autodetect:
+        schema_matrix.append({
+            'id': 'autodetect',
+            'description': 'Auto schema detection',
+            'read': True,
+            'write': False
+        })
+
     return schema_matrix
 
 
