@@ -136,17 +136,27 @@ class ISO19139OutputSchema(BaseOutputSchema):
 
         mcf['identification']['extents'] = {
             'spatial': [{
-                'bbox': [
+                'bbox': []
+            }],
+            'temporal': []
+        }
+        try:
+            mcf['identification']['extents']['spatial'][0]['bbox'] = [
                     ast.literal_eval(identification.extent.boundingBox.minx),
                     ast.literal_eval(identification.extent.boundingBox.miny),
                     ast.literal_eval(identification.extent.boundingBox.maxx),
                     ast.literal_eval(identification.extent.boundingBox.maxy)
                 ]
-            }],
-            'temporal': []
+        except ValueError as err:
+            LOGGER.info(f'boundingBox empty: {err}')
+        except AttributeError as err:
+            LOGGER.info(f'boundingBox missing: {err}')
+
+        temp_extent = {
+            'begin': None,
+            'end': None
         }
 
-        temp_extent = {}
         if identification.temporalextent_start:
             temp_extent['begin'] = identification.temporalextent_start
         if identification.temporalextent_end:
@@ -160,9 +170,8 @@ class ISO19139OutputSchema(BaseOutputSchema):
         mcf['identification']['status'] = identification.status
 
         LOGGER.debug('Setting contacts')
-#        for contact in m.get_all_contacts():
-#            mcf['contact'].update(get_contact(contact))
-        mcf['contact'].update(get_contact(m.contact[0]))
+        for contact in m.get_all_contacts():
+            mcf['contact'].update(get_contact(contact))
 
         LOGGER.debug('Setting distribution')
         if m.distribution:
